<?php
	/*	
	*	Fundraise Master Plugin
	*	---------------------------------------------------------------------
	*	for cause post type
	*	---------------------------------------------------------------------
	*/

	// create post type
	add_action('init', 'frmaster_cause_init');
	if( !function_exists('frmaster_cause_init') ){
		function frmaster_cause_init(){
			
			// custom post type
			$slug = apply_filters('frmaster_custom_post_slug', 'cause', 'cause');
			$supports = apply_filters('frmaster_custom_post_support', array('title', 'editor', 'author', 'thumbnail', 'comments', 'excerpt', 'custom-fields', 'revisions'), 'cause');

			$labels = array(
				'name'               => esc_html__('Cause', 'frmaster'),
				'singular_name'      => esc_html__('Cause', 'frmaster'),
				'menu_name'          => esc_html__('Cause', 'frmaster'),
				'name_admin_bar'     => esc_html__('Cause', 'frmaster'),
				'add_new'            => esc_html__('Add New', 'frmaster'),
				'add_new_item'       => esc_html__('Add New Cause', 'frmaster'),
				'new_item'           => esc_html__('New Cause', 'frmaster'),
				'edit_item'          => esc_html__('Edit Cause', 'frmaster'),
				'view_item'          => esc_html__('View Cause', 'frmaster'),
				'all_items'          => esc_html__('All Cause', 'frmaster'),
				'search_items'       => esc_html__('Search Cause', 'frmaster'),
				'parent_item_colon'  => esc_html__('Parent Cause:', 'frmaster'),
				'not_found'          => esc_html__('No cause found.', 'frmaster'),
				'not_found_in_trash' => esc_html__('No cause found in Trash.', 'frmaster')
			);
			$args = array(
				'labels'             => $labels,
				'description'        => esc_html__('Description.', 'frmaster'),
				'public'             => true,
				'publicly_queryable' => true,
				'exclude_from_search'=> false,
				'show_ui'            => true,
				'show_in_menu'       => true,
				'query_var'          => true,
				'rewrite'            => array('slug' => $slug),
				'map_meta_cap' 		 => true,
				'capabilities' => array(
					'edit_post'          => 'edit_cause', 
					'read_post'          => 'read_cause', 
					'delete_post'        => 'delete_cause', 
					'delete_posts'       => 'delete_causes', 
					'edit_posts'         => 'edit_causes', 
					'create_posts'       => 'edit_causes', 
					'edit_others_posts'  	=> 'edit_others_causes', 
					'delete_others_posts '  => 'edit_others_causes', 
					'publish_posts'      	=> 'publish_causes',       
					'edit_published_posts' 	=> 'publish_causes',       
					'read_private_posts' 	=> 'read_private_causes', 
					'edit_private_posts' 	=> 'read_private_causes', 
					'delete_private_posts' 	=> 'read_private_causes', 
				),
				'has_archive'        => false,
				'hierarchical'       => false,
				'menu_position'      => null,
				'supports'           => $supports
			);
			register_post_type('cause', $args);

			// custom taxonomy
			$slug = apply_filters('frmaster_custom_post_slug', 'cause-category', 'cause_category');
			$args = array(
				'hierarchical'      => true,
				'label'             => esc_html__('Cause Category', 'frmaster'),
				'show_ui'           => true,
				'show_admin_column' => true,
				'query_var'         => true,
				'rewrite'           => array('slug' => $slug),
				'capabilities'		=> array(
					'manage_terms' => 'manage_cause_category', 
					'edit_terms' => 'manage_cause_category', 
					'delete_terms' => 'manage_cause_category', 
					'assign_terms' => 'manage_cause_category'
				)
			);
			register_taxonomy('cause_category', array('cause'), $args);
			register_taxonomy_for_object_type('cause_category', 'cause');

			$slug = apply_filters('frmaster_custom_post_slug', 'cause-tag', 'cause_tag');
			$args = array(
				'hierarchical'      => false,
				'label'             => esc_html__('Cause Tag', 'frmaster'),
				'show_ui'           => true,
				'show_admin_column' => true,
				'query_var'         => true,
				'rewrite'           => array('slug' => $slug),
				'capabilities'		=> array(
					'manage_terms' => 'manage_cause_tag', 
					'edit_terms' => 'manage_cause_tag', 
					'delete_terms' => 'manage_cause_tag', 
					'assign_terms' => 'manage_cause_tag'
				)
			);
			register_taxonomy('cause_tag', array('cause'), $args);
			register_taxonomy_for_object_type('cause_tag', 'cause');

			// apply single template filter
			add_filter('single_template', 'frmaster_cause_template');

		}
	} // frmaster_post_type_init

	if( !function_exists('frmaster_cause_template') ){
		function frmaster_cause_template( $template ){

			if( get_post_type() == 'cause' ){
				$template = FRMASTER_LOCAL . '/single/cause.php';
			}

			return $template;
		}
	}

	// add page builder to cause
	if( is_admin() ){ add_filter('gdlr_core_page_builder_post_type', 'frmaster_gdlr_core_cause_add_page_builder'); }
	if( !function_exists('frmaster_gdlr_core_cause_add_page_builder') ){
		function frmaster_gdlr_core_cause_add_page_builder( $post_type ){
			$post_type[] = 'cause';
			return $post_type;
		}
	}	

	// init page builder value
	if( is_admin() ){ add_filter('gdlr_core_cause_page_builder_val_init', 'frmaster_cause_page_builder_val_init'); }
	if( !function_exists('frmaster_cause_page_builder_val_init') ){
		function frmaster_cause_page_builder_val_init( $value ){
			$value = '[{"template":"wrapper","type":"background","value":{"id":"","class":"","privacy":"","content-layout":"full","max-width-wrapper":"","max-width":"","enable-space":"disable","hide-this-wrapper-in":"none","animation":"none","animation-location":"0.8","z-index":"","full-height":"disable","decrease-height":"0px","centering-content":"disable","background-type":"color","background-color-style":"plain","background-color":"","background-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-top-offset":"","background-image-bottom-offset":"","mobile-background-image":"","background-image-style":"cover","background-image-position":"center","background-image-position-custom":"","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-opacity":"","background-filter":"none","background-blur-size":"","pattern-opacity":"1","parallax-speed":"0.8","overflow":"","enable-container-background":"disable","container-background-color":"","container-background-gradient":"none","container-background-gradient-min-opacity":"","container-background-gradient-color":"","container-background-image":"","container-background-image-opacity":"","container-padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"container-margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"container-border-radius":"","container-shadow-size":"","container-shadow-color":"","container-shadow-opacity":"0.2","container-z-index":"","wrapper-background-gradient":"none","wrapper-background-gradient-color":"#000","wrapper-background-top-gradient-size":"413px","wrapper-background-bottom-gradient-size":"413px","enable-background-image-overlay":"disable","background-image-overlay":"","background-image-overlay-section":"left","background-image-overlay-margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"enable-background-particle":"disable","enable-marquee":"disable","marquee-text":"","marquee-position":"top","marquee-position-offset":"","marquee-speed":"10000","marquee-direction":"left","marquee-font-size":"","marquee-font-weight":"","marquee-font-letter-spacing":"","marquee-text-color":"","marquee-opacity":"1","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"10px","left":"0px","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"element","type":"content-navigation","value":{"id":"","class":"","tabs":[{"id":"story","title":"Story"},{"id":"faq","title":"FAQ"},{"id":"updates","title":"Updates"},{"id":"comments","title":"Comments"}],"background-color":"#ffffff","text-color":"#afafaf","text-active-color":"#121212","enable-bottom-border":"enable","border-color":"#ebebeb","slide-bar-color":"#2123bc","padding-bottom":"30px"}}]},{"template":"wrapper","type":"sidebar","value":{"id":"story","class":"","content-layout":"boxed","sidebar":"right","sidebar-left":"gdlr-core-sidebar-preset","sidebar-right":"gdlr-core-sidebar2","sidebar-width":"20","enable-sticky-sidebar":"disable","hide-this-wrapper-in":"none","margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"padding":{"top":"60px","right":"10px","bottom":"30px","left":"0px","settings":"unlink"},"background-type":"color","background-color":"","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","pattern-opacity":"1","parallax-speed":"0.8","skin":"","sidebar-padding":{"top":"60px","right":"0px","bottom":"30px","left":"0px","settings":"unlink"},"sidebar-background-color":"","sidebar-skin":""},"items":[{"template":"wrapper","type":"column","column":"60","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"","centering-sync-height-content":"disable","background-type":"color","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"45px","left":"0px","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"element","type":"title","value":{"id":"","class":"","title":"How did this come to our attention?","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"24px","mobile-title-font-size":"","title-font-weight":"700","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#070707","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"30px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>During the 19th century a profusion of charitable organizations emerged to alleviate the awful conditions of the working class in the slums. The Labourer\'s Friend Society, chaired by Lord Shaftesbury in the United Kingdom in 1830, aimed to improve working-class conditions. It promoted, for example, the allotment of land to labourers for \"cottage husbandry\" that later became the allotment movement. In 1844 it became the first Model Dwellings Company.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"#646464","margin-left":"","margin-right":"","padding-bottom":"30px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>There was strong growth in municipal charities. The Brougham Commission led on to the Municipal Corporations Act 1835, which reorganized multiple local charities by incorporating them into single entities under supervision from local government.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"#646464","margin-left":"","margin-right":"","padding-bottom":"0px"}}]},{"template":"wrapper","type":"column","column":"60","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"","centering-sync-height-content":"disable","background-type":"color","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"70px","left":"0px","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"element","type":"divider","value":{"id":"","class":"","type":"normal","icon-type":"icon","image":"","icon":"fa fa-film","style":"solid","align":"center","divider-type":"horizontal","vertical-divider-icon":"","vertical-divider-text":"","icon-size":"15px","divider-size":"4px","divider-width":"","divider-border-radius":"","margin-top":"","margin-left":"","margin-right":"","padding-bottom":"25px","vdi-font-size":"","vd-font-size":"","vd-font-weight":"","vd-font-letter-spacing":"","vd-text-transform":"uppercase","icon-color":"","divider-color":"#2123bc"}},{"template":"element","type":"title","value":{"id":"","class":"","title":"Clean water, sanitation, and hygiene education are basic necessities for a healthy environment and a productive life and well life being","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"27px","mobile-title-font-size":"","title-font-weight":"400","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#2123bc","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"0px"}}]},{"template":"wrapper","type":"column","column":"20","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"h1","centering-sync-height-content":"disable","background-type":"color","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":"icon-cause"},"items":[{"template":"element","type":"column-service","value":{"id":"","class":"","media-type":"image","icon":"fa fa-gear","icon-style":"normal","image":"7758","character":"","title":"100K","caption":"","caption-position":"bottom","content":"<p>Children Helped</p>","read-more-text":"","read-more-link":"#","read-more-link-target":"_self","enable-read-more-icon":"disable","read-more-icon":"","style":"center_icon-top","icon-size":"30px","title-size":"28px","title-font-weight":"700","title-letter-spacing":"0px","title-text-transform":"none","caption-size":"14px","caption-font-weight":"","caption-font-style":"default","caption-text-transform":"uppercase","content-size":"17px","content-font-weight":"500","content-text-transform":"none","read-more-size":"14px","read-more-font-weight":"","read-more-font-style":"default","read-more-icon-font-size":"","icon-color":"","icon-background":"","background-color":"","media-margin":{"top":"","right":"","bottom":"16px","left":""},"media-image-max-width":"","character-width":"","title-top-padding":"","title-bottom-margin":"0px","caption-top-margin":"","read-more-top-margin":"","padding":{"top":"","right":"","bottom":"30px","left":"","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"}}}]},{"template":"wrapper","type":"column","column":"20","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"h1","centering-sync-height-content":"disable","background-type":"color","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":"icon-cause"},"items":[{"template":"element","type":"column-service","value":{"id":"","class":"","media-type":"image","icon":"fa fa-gear","icon-style":"normal","image":"7757","character":"","title":"18000","caption":"","caption-position":"bottom","content":"<p>Volunteers Worldwide</p>","read-more-text":"","read-more-link":"#","read-more-link-target":"_self","enable-read-more-icon":"disable","read-more-icon":"","style":"center_icon-top","icon-size":"30px","title-size":"28px","title-font-weight":"700","title-letter-spacing":"0px","title-text-transform":"none","caption-size":"14px","caption-font-weight":"","caption-font-style":"default","caption-text-transform":"uppercase","content-size":"17px","content-font-weight":"500","content-text-transform":"none","read-more-size":"14px","read-more-font-weight":"","read-more-font-style":"default","read-more-icon-font-size":"","icon-color":"","icon-background":"","background-color":"","media-margin":{"top":"","right":"","bottom":"16px","left":""},"media-image-max-width":"","character-width":"","title-top-padding":"","title-bottom-margin":"0px","caption-top-margin":"","read-more-top-margin":"","padding":{"top":"","right":"","bottom":"30px","left":"","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"}}}]},{"template":"wrapper","type":"column","column":"20","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"h1","centering-sync-height-content":"disable","background-type":"color","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":"icon-cause"},"items":[{"template":"element","type":"column-service","value":{"id":"","class":"","media-type":"image","icon":"fa fa-gear","icon-style":"normal","image":"7756","character":"","title":"$100M","caption":"","caption-position":"bottom","content":"<p>Fund raised</p>","read-more-text":"","read-more-link":"#","read-more-link-target":"_self","enable-read-more-icon":"disable","read-more-icon":"","style":"center_icon-top","icon-size":"30px","title-size":"28px","title-font-weight":"700","title-letter-spacing":"0px","title-text-transform":"none","caption-size":"14px","caption-font-weight":"","caption-font-style":"default","caption-text-transform":"uppercase","content-size":"17px","content-font-weight":"500","content-text-transform":"none","read-more-size":"14px","read-more-font-weight":"","read-more-font-style":"default","read-more-icon-font-size":"","icon-color":"","icon-background":"","background-color":"","media-margin":{"top":"","right":"","bottom":"16px","left":""},"media-image-max-width":"","character-width":"","title-top-padding":"","title-bottom-margin":"0px","caption-top-margin":"","read-more-top-margin":"","padding":{"top":"","right":"","bottom":"30px","left":"","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"}}}]},{"template":"wrapper","type":"column","column":"60","items":[{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>During the 19th century a profusion of charitable organizations emerged to alleviate the awful conditions of the working class in the slums. The Labourer\'s Friend Society, chaired by Lord Shaftesbury in the United Kingdom in 1830, aimed to improve working-class conditions.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"#646464","margin-left":"","margin-right":"","padding-bottom":"40px"}},{"template":"element","type":"icon-list","value":{"id":"","class":"","tabs":[{"image":"","image-img":"","icon":"icon-check","icon-hover":"","title":"Provide long-term campaign planning","caption":"","link-url":"","link-target":"_self"},{"image":"","image-img":"","icon":"icon-check","icon-hover":"","title":"Reduce our long term administration costs","caption":"","link-url":"","link-target":"_self"},{"image":"","image-img":"","icon":"icon-check","icon-hover":"","title":"Remain fiercely independent and unbiased","caption":"","link-url":"","link-target":"_self"},{"image":"","image-img":"","icon":"icon-check","icon-hover":"","title":"Regular updates on what\'s happening in our priority campaigns ","caption":"","link-url":"","link-target":"_self"},{"image":"","image-img":"","icon":"icon-check","icon-hover":"","title":"Invitations to events and other exciting opportunities to take action","caption":"","link-url":"","link-target":"_self"}],"columns":"60","align":"left","enable-divider":"disable","icon-background":"none","icon-position":"left","icon-color":"#2123bc","icon-background-color":"","content-color":"#3b3b3b","caption-color":"","border-color":"","icon-size":"20px","content-size":"18px","content-font-weight":"400","content-text-transform":"","content-letter-spacing":"","caption-size":"18px","caption-font-weight":"","caption-text-transform":"","caption-letter-spacing":"","image-max-width":"","icon-top-margin":"","icon-right-margin":"","list-bottom-margin":"10px","padding-bottom":"30px"}}]}]},{"template":"wrapper","type":"background","value":{"id":"","class":"","privacy":"","content-layout":"boxed","max-width-wrapper":"","max-width":"","enable-space":"disable","hide-this-wrapper-in":"none","animation":"none","animation-location":"0.8","z-index":"","full-height":"disable","decrease-height":"0px","centering-content":"disable","background-type":"image","background-color-style":"plain","background-color":"","background-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"7759","background-image-top-offset":"","background-image-bottom-offset":"","mobile-background-image":"","background-image-style":"cover","background-image-position":"center","background-image-position-custom":"","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-opacity":"","background-filter":"none","background-blur-size":"","pattern-opacity":"1","parallax-speed":"0.05","overflow":"","enable-container-background":"disable","container-background-color":"","container-background-gradient":"none","container-background-gradient-min-opacity":"","container-background-gradient-color":"","container-background-image":"","container-background-image-opacity":"","container-padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"container-margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"container-border-radius":"","container-shadow-size":"","container-shadow-color":"","container-shadow-opacity":"0.2","container-z-index":"","wrapper-background-gradient":"none","wrapper-background-gradient-color":"#000","wrapper-background-top-gradient-size":"413px","wrapper-background-bottom-gradient-size":"413px","enable-background-image-overlay":"disable","background-image-overlay":"","background-image-overlay-section":"left","background-image-overlay-margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"enable-background-particle":"disable","enable-marquee":"disable","marquee-text":"","marquee-position":"top","marquee-position-offset":"","marquee-speed":"10000","marquee-direction":"left","marquee-font-size":"","marquee-font-weight":"","marquee-font-letter-spacing":"","marquee-text-color":"","marquee-opacity":"1","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","padding":{"top":"90px","right":"0px","bottom":"55px","left":"0px","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"30px","right":"","bottom":"40px","left":"","settings":"unlink"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"wrapper","type":"column","column":"24","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"","centering-sync-height-content":"disable","background-type":"color","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"30px","right":"0px","bottom":"0px","left":"0px","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"unlink"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"element","type":"title","value":{"id":"","class":"","title":"How did this come to our attention?","caption":"The Story of us","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"33px","mobile-title-font-size":"","title-font-weight":"700","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"14px","caption-font-weight":"700","caption-font-style":"normal","caption-font-letter-spacing":"4px","caption-font-uppercase":"enable","title-link-text-size":"","left-icon-color":"","title-color":"#ffffff","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"#c2c2ff","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"20px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>The unincorporated association is the most common form of organization within the voluntary sector in England and Wales.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"20px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"#b1b2ff","margin-left":"","margin-right":"","padding-bottom":"35px"}},{"template":"element","type":"button","value":{"id":"","class":"","button-text":"Download PDF","link-to":"custom-url","custom-image":"","video-url":"","button-link":"#","button-link-target":"_self","icon-position":"left","icon":"fa fa-file-pdf-o","text-align":"left","full-width-button":"disable","button-padding":{"top":"13px","right":"33px","bottom":"16px","left":"33px","settings":"unlink"},"border-radius":"0px","button-background":"solid","button-border":"enable","border-width":{"top":"2px","right":"2px","bottom":"2px","left":"2px","settings":"link"},"border-on-text-size":"","border-on-text-top-margin":"","text-color":"#ffffff","icon-color":"","text-hover-color":"","icon-hover-color":"","background-color":"#3230b2","background-hover-color":"","background-gradient-color":"","border-color":"#ffffff","border-hover-color":"","border-on-text-color":"","button-shadow-size":"","button-shadow-color":"","button-shadow-opacity":"0.2","button2-text":"","button2-link-to":"custom-url","button2-custom-image":"","button2-video-url":"","button2-button-link":"","button2-link-target":"_self","button2-icon-position":"none","button2-icon":"fa fa-gear","button2-padding":{"top":"15px","right":"33px","bottom":"15px","left":"33px","settings":"unlink"},"border2-radius":"25px","button2-background":"gradient","button2-border":"disable","border2-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"border2-on-text-size":"","border2-on-text-top-margin":"","text2-color":"","icon2-color":"","text2-hover-color":"","icon2-hover-color":"","background2-color":"","background2-hover-color":"","background2-gradient-color":"","border2-color":"","border2-hover-color":"","border2-on-text-color":"","button2-shadow-size":"","button2-shadow-color":"","button2-shadow-opacity":"0.2","text-size":"12px","text-font-weight":"700","text-letter-spacing":"1px","text-transform":"","icon-size":"","button2-left-margin":"10px","item-top-margin":"0px","padding-bottom":"0px"}}]},{"template":"wrapper","type":"column","column":"36","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"","centering-sync-height-content":"disable","background-type":"color","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"0px","left":"40px","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"50px","right":"","bottom":"","left":"","settings":"unlink"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"element","type":"video","value":{"id":"","class":"","privacy":"","video-type":"youtube","video-url":"https://www.youtube.com/watch?v=QFy8iPBYDLU","video-url-mp4":"","video-url-webm":"","video-url-ogg":"","autoplay":"disable","loop":"disable","padding-bottom":"30px"}}]}]},{"template":"wrapper","type":"background","value":{"id":"faq","class":"","privacy":"","content-layout":"boxed","max-width-wrapper":"","max-width":"","enable-space":"disable","hide-this-wrapper-in":"none","animation":"none","animation-location":"0.8","z-index":"","full-height":"disable","decrease-height":"0px","centering-content":"disable","background-type":"color","background-color-style":"plain","background-color":"","background-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-top-offset":"","background-image-bottom-offset":"","mobile-background-image":"","background-image-style":"cover","background-image-position":"center","background-image-position-custom":"","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-opacity":"","background-filter":"none","background-blur-size":"","pattern-opacity":"1","parallax-speed":"0.8","overflow":"","enable-container-background":"disable","container-background-color":"","container-background-gradient":"none","container-background-gradient-min-opacity":"","container-background-gradient-color":"","container-background-image":"","container-background-image-opacity":"","container-padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"container-margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"container-border-radius":"","container-shadow-size":"","container-shadow-color":"","container-shadow-opacity":"0.2","container-z-index":"","wrapper-background-gradient":"none","wrapper-background-gradient-color":"#000","wrapper-background-top-gradient-size":"413px","wrapper-background-bottom-gradient-size":"413px","enable-background-image-overlay":"disable","background-image-overlay":"","background-image-overlay-section":"left","background-image-overlay-margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"enable-background-particle":"disable","enable-marquee":"disable","marquee-text":"","marquee-position":"top","marquee-position-offset":"","marquee-speed":"10000","marquee-direction":"left","marquee-font-size":"","marquee-font-weight":"","marquee-font-letter-spacing":"","marquee-text-color":"","marquee-opacity":"1","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","padding":{"top":"80px","right":"0px","bottom":"60px","left":"0px","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"60px","right":"","bottom":"65px","left":"","settings":"unlink"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"wrapper","type":"column","column":"60","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"","centering-sync-height-content":"disable","background-type":"color","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"10px","left":"0px","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"element","type":"title","value":{"id":"","class":"","title":"FAQ","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"24px","mobile-title-font-size":"","title-font-weight":"700","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"enable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#070707","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"30px"}}]},{"template":"wrapper","type":"column","column":"30","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"","centering-sync-height-content":"disable","background-type":"color","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"element","type":"title","value":{"id":"","class":"","title":"What is Chariti?","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"16px","mobile-title-font-size":"","title-font-weight":"500","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#2123bc","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"15px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>- During the 19th century a profusion of charitable organizations emerged to alleviate the awful conditions of the working class in the slums. The Labourer\'s Friend Society, chaired by Lord Shaftesbury in the United Kingdom in 1830, aimed to improve working-class conditions.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"","margin-left":"","margin-right":"","padding-bottom":"25px"}},{"template":"element","type":"divider","value":{"id":"","class":"","type":"normal","icon-type":"icon","image":"","icon":"fa fa-film","style":"solid","align":"center","divider-type":"horizontal","vertical-divider-icon":"","vertical-divider-text":"","icon-size":"15px","divider-size":"1px","divider-width":"","divider-border-radius":"","margin-top":"","margin-left":"","margin-right":"","padding-bottom":"25px","vdi-font-size":"","vd-font-size":"","vd-font-weight":"","vd-font-letter-spacing":"","vd-text-transform":"uppercase","icon-color":"","divider-color":"#e5e5e5"}},{"template":"element","type":"title","value":{"id":"","class":"","title":"How do you make sure my gifts to Chariti are spent wisely?","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"16px","mobile-title-font-size":"","title-font-weight":"500","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#2123bc","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"15px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>- In the Enlightenment era charitable and philanthropic activity among voluntary associations and rich benefactors became a widespread cultural practice.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"","margin-left":"","margin-right":"","padding-bottom":"27px"}},{"template":"element","type":"divider","value":{"id":"","class":"","type":"normal","icon-type":"icon","image":"","icon":"fa fa-film","style":"solid","align":"center","divider-type":"horizontal","vertical-divider-icon":"","vertical-divider-text":"","icon-size":"15px","divider-size":"1px","divider-width":"","divider-border-radius":"","margin-top":"","margin-left":"","margin-right":"","padding-bottom":"25px","vdi-font-size":"","vd-font-size":"","vd-font-weight":"","vd-font-letter-spacing":"","vd-text-transform":"uppercase","icon-color":"","divider-color":"#e5e5e5"}},{"template":"element","type":"title","value":{"id":"","class":"","title":"How do you know which children need help?","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"16px","mobile-title-font-size":"","title-font-weight":"500","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#2123bc","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"15px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>- Charities also began to adopt campaigning roles, where they would champion a cause and lobby the government for legislative change.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"","margin-left":"","margin-right":"","padding-bottom":"27px"}},{"template":"element","type":"divider","value":{"id":"","class":"","type":"normal","icon-type":"icon","image":"","icon":"fa fa-film","style":"solid","align":"center","divider-type":"horizontal","vertical-divider-icon":"","vertical-divider-text":"","icon-size":"15px","divider-size":"1px","divider-width":"","divider-border-radius":"","margin-top":"","margin-left":"","margin-right":"","padding-bottom":"25px","vdi-font-size":"","vd-font-size":"","vd-font-weight":"","vd-font-letter-spacing":"","vd-text-transform":"uppercase","icon-color":"","divider-color":"#e5e5e5"}},{"template":"element","type":"title","value":{"id":"","class":"","title":"Is my donation tax-deductible?","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"16px","mobile-title-font-size":"","title-font-weight":"500","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#2123bc","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"15px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>- If you’re in the U.S., yes, you can.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"","margin-left":"","margin-right":"","padding-bottom":"27px"}},{"template":"element","type":"divider","value":{"id":"","class":"","type":"normal","icon-type":"icon","image":"","icon":"fa fa-film","style":"solid","align":"center","divider-type":"horizontal","vertical-divider-icon":"","vertical-divider-text":"","icon-size":"15px","divider-size":"1px","divider-width":"","divider-border-radius":"","margin-top":"","margin-left":"","margin-right":"","padding-bottom":"25px","vdi-font-size":"","vd-font-size":"","vd-font-weight":"","vd-font-letter-spacing":"","vd-text-transform":"uppercase","icon-color":"","divider-color":"#e5e5e5"}}]},{"template":"wrapper","type":"column","column":"30","items":[{"template":"element","type":"title","value":{"id":"","class":"","title":"Where does my money actually go? ","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"16px","mobile-title-font-size":"","title-font-weight":"500","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#2123bc","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"15px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>- In the Enlightenment era charitable and philanthropic activity among voluntary associations and rich benefactors became a widespread cultural practice.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"","margin-left":"","margin-right":"","padding-bottom":"25px"}},{"template":"element","type":"divider","value":{"id":"","class":"","type":"normal","icon-type":"icon","image":"","icon":"fa fa-film","style":"solid","align":"center","divider-type":"horizontal","vertical-divider-icon":"","vertical-divider-text":"","icon-size":"15px","divider-size":"1px","divider-width":"","divider-border-radius":"","margin-top":"","margin-left":"","margin-right":"","padding-bottom":"25px","vdi-font-size":"","vd-font-size":"","vd-font-weight":"","vd-font-letter-spacing":"","vd-text-transform":"uppercase","icon-color":"","divider-color":"#e5e5e5"}},{"template":"element","type":"title","value":{"id":"","class":"","title":"How do you choose locations to build a community center?","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"16px","mobile-title-font-size":"","title-font-weight":"500","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#2123bc","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"15px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>- This emerging upper-class fashion for benevolence resulted in the incorporation of the first charitable organizations.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"","margin-left":"","margin-right":"","padding-bottom":"27px"}},{"template":"element","type":"divider","value":{"id":"","class":"","type":"normal","icon-type":"icon","image":"","icon":"fa fa-film","style":"solid","align":"center","divider-type":"horizontal","vertical-divider-icon":"","vertical-divider-text":"","icon-size":"15px","divider-size":"1px","divider-width":"","divider-border-radius":"","margin-top":"","margin-left":"","margin-right":"","padding-bottom":"25px","vdi-font-size":"","vd-font-size":"","vd-font-weight":"","vd-font-letter-spacing":"","vd-text-transform":"uppercase","icon-color":"","divider-color":"#e5e5e5"}},{"template":"element","type":"title","value":{"id":"","class":"","title":"What percentage of my donation goes towards programs?","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"16px","mobile-title-font-size":"","title-font-weight":"500","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#2123bc","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"15px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>- The Enlightenment also saw growing philosophical debate between those who championed state intervention and those who believed that private charities should provide welfare. The Reverend Thomas Malthus.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"","margin-left":"","margin-right":"","padding-bottom":"27px"}},{"template":"element","type":"divider","value":{"id":"","class":"","type":"normal","icon-type":"icon","image":"","icon":"fa fa-film","style":"solid","align":"center","divider-type":"horizontal","vertical-divider-icon":"","vertical-divider-text":"","icon-size":"15px","divider-size":"1px","divider-width":"","divider-border-radius":"","margin-top":"","margin-left":"","margin-right":"","padding-bottom":"25px","vdi-font-size":"","vd-font-size":"","vd-font-weight":"","vd-font-letter-spacing":"","vd-text-transform":"uppercase","icon-color":"","divider-color":"#e5e5e5"}},{"template":"element","type":"title","value":{"id":"","class":"","title":"What’s your goal?","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"16px","mobile-title-font-size":"","title-font-weight":"500","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#2123bc","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"15px"}},{"template":"element","type":"text-box","value":{"id":"","class":"","content":"<p>- Charities also began to adopt campaigning roles, where they would champion a cause and lobby the government for legislative change.</p>","text-align":"left","apply-the-content-filter":"disable","enable-p-space":"disable","font-size":"16px","content-font-weight":"400","content-letter-spacing":"0px","content-text-transform":"none","text-color":"","margin-left":"","margin-right":"","padding-bottom":"0px"}}]}]},{"template":"wrapper","type":"background","value":{"id":"updates","class":"","privacy":"","content-layout":"boxed","max-width-wrapper":"","max-width":"","enable-space":"disable","hide-this-wrapper-in":"none","animation":"none","animation-location":"0.8","z-index":"","full-height":"disable","decrease-height":"0px","centering-content":"disable","background-type":"image","background-color-style":"plain","background-color":"","background-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"7760","background-image-top-offset":"","background-image-bottom-offset":"","mobile-background-image":"","background-image-style":"cover","background-image-position":"center","background-image-position-custom":"","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-opacity":"","background-filter":"none","background-blur-size":"","pattern-opacity":"1","parallax-speed":"0.05","overflow":"","enable-container-background":"disable","container-background-color":"","container-background-gradient":"none","container-background-gradient-min-opacity":"","container-background-gradient-color":"","container-background-image":"","container-background-image-opacity":"","container-padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"container-margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"container-border-radius":"","container-shadow-size":"","container-shadow-color":"","container-shadow-opacity":"0.2","container-z-index":"","wrapper-background-gradient":"none","wrapper-background-gradient-color":"#000","wrapper-background-top-gradient-size":"413px","wrapper-background-bottom-gradient-size":"413px","enable-background-image-overlay":"disable","background-image-overlay":"","background-image-overlay-section":"left","background-image-overlay-margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"enable-background-particle":"disable","enable-marquee":"disable","marquee-text":"","marquee-position":"top","marquee-position-offset":"","marquee-speed":"10000","marquee-direction":"left","marquee-font-size":"","marquee-font-weight":"","marquee-font-letter-spacing":"","marquee-text-color":"","marquee-opacity":"1","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","padding":{"top":"75px","right":"0px","bottom":"80px","left":"0px","settings":"unlink"},"margin":{"top":"0px","right":"0px","bottom":"60px","left":"0px","settings":"unlink"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"55px","right":"","bottom":"60px","left":"","settings":"unlink"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":""},"items":[{"template":"wrapper","type":"column","column":"60","items":[{"template":"element","type":"title","value":{"id":"","class":"","title":"Updates","caption":"","caption-position":"top","title-width":"300px","title-link-text":"","title-link":"","title-link-target":"_self","text-align":"left","left-media-type":"image","left-icon":"fa fa-gear","left-image":"","left-divider-size":"","left-divider-margin":"","title-left-icon":"none","enable-side-border":"disable","side-border-alignment":"upper-left","side-border-width":"30px","side-border-size":"1px","side-border-spaces":"30px","side-border-radius":"","side-border-style":"solid","side-border-divider-color":"","heading-tag":"h3","icon-font-size":"30px","title-font-size":"24px","mobile-title-font-size":"","title-font-weight":"700","title-font-style":"normal","title-font-letter-spacing":"0px","title-line-height":"","title-font-uppercase":"disable","caption-font-size":"16px","caption-font-weight":"400","caption-font-style":"italic","caption-font-letter-spacing":"0px","caption-font-uppercase":"disable","title-link-text-size":"","left-icon-color":"","title-color":"#ffffff","title-link-hover-color":"","title-text-shadow-size":"","title-text-shadow-color":"","caption-color":"","item-left-margin":"","caption-spaces":"10px","caption-right-top-padding":"","media-margin":{"top":"10px","right":"30px","bottom":"0px","left":"0px","settings":"unlink"},"padding-bottom":"50px"}}]},{"template":"wrapper","type":"column","column":"60","value":{"id":"","class":"","privacy":"","max-width":"","min-height":"","enable-left-right-spaces":"disable","hide-this-wrapper-in":"none","tablet-size":"","animation":"none","animation-location":"0.8","column-link":"","column-link-target":"_self","z-index":"","full-height":"disable","decrease-height":"0px","sync-height":"","centering-sync-height-content":"disable","background-type":"image","background-color-style":"plain","background-extending":"none","background-color":"","background-normal-color-opacity":"1","background-gradient-color":"","background-gradient-color-opacity":"1","background-image":"","background-image-style":"cover","background-image-position":"center","background-video-url":"","background-video-url-mp4":"","background-video-url-webm":"","background-video-url-ogg":"","background-video-image":"","background-pattern":"pattern-1","background-color-opacity":"1","background-opacity":"1","background-filter":"none","background-blur-size":"","border-radius":{"top":"","right":"","bottom":"","left":"","settings":"link"},"parallax-speed":"0.8","overflow":"","border-type":"none","border-pre-spaces":{"top":"20px","right":"20px","bottom":"20px","left":"20px","settings":"link"},"border-width":{"top":"1px","right":"1px","bottom":"1px","left":"1px","settings":"link"},"hover-border-width":{"top":"","right":"","bottom":"","left":"","settings":"link"},"border-color":"#ffffff","hover-border-color":"#ffffff","border-style":"solid","background-shadow-size":"","background-shadow-color":"","background-shadow-opacity":"0.2","enable-move-up-shadow-effect":"disable","move-up-effect-length":"","frame-hover-shadow-size":"","frame-hover-shadow-color":"","frame-hover-shadow-opacity":"0.2","padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"margin":{"top":"0px","right":"0px","bottom":"0px","left":"0px","settings":"link"},"tablet-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"tablet-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-padding":{"top":"","right":"","bottom":"","left":"","settings":"link"},"mobile-margin":{"top":"","right":"","bottom":"","left":"","settings":"link"},"skin":"acc-cause"},"items":[{"template":"element","type":"accordion","value":{"id":"","class":"","tabs":[{"head-text":"","title":"August 15, 2020","content":"<p>Financial figures (e.g. tax refund, revenue from fundraising, revenue from sale of goods and services or revenue from investment) are indicators to assess the financial sustainability of a charity, especially to charity evaluators. This information can impact a charity\'s reputation with donors and societies, and thus the charity\'s financial gains.</p><p>Charitable organizations often depend partly on donations from businesses. Such donations to charitable organizations represent a major form of corporate philanthropy.</p>"},{"head-text":"","title":"July 22, 2020","content":"<p>Financial figures (e.g. tax refund, revenue from fundraising, revenue from sale of goods and services or revenue from investment) are indicators to assess the financial sustainability of a charity, especially to charity evaluators. This information can impact a charity\'s reputation with donors and societies, and thus the charity\'s financial gains.</p><p>Charitable organizations often depend partly on donations from businesses. Such donations to charitable organizations represent a major form of corporate philanthropy.</p>"},{"head-text":"","title":"July 09, 2020","content":"<p>Financial figures (e.g. tax refund, revenue from fundraising, revenue from sale of goods and services or revenue from investment) are indicators to assess the financial sustainability of a charity, especially to charity evaluators. This information can impact a charity\'s reputation with donors and societies, and thus the charity\'s financial gains.</p><p>Charitable organizations often depend partly on donations from businesses. Such donations to charitable organizations represent a major form of corporate philanthropy.</p>"},{"head-text":"","title":"April 09, 2020","content":"<p>Financial figures (e.g. tax refund, revenue from fundraising, revenue from sale of goods and services or revenue from investment) are indicators to assess the financial sustainability of a charity, especially to charity evaluators. This information can impact a charity\'s reputation with donors and societies, and thus the charity\'s financial gains.</p><p>Charitable organizations often depend partly on donations from businesses. Such donations to charitable organizations represent a major form of corporate philanthropy.</p>"}],"active":"1","allow-closing-all-tabs":"disable","style":"background-title-icon","with-divider":"disable","align":"left","icon-position":"right","padding-bottom":"0px","title-font-size":"13px","title-font-weight":"600","title-letter-spacing":"1px","title-text-transform":"default","title-padding":{"top":"","right":"","bottom":"","left":"","settings":"unlink"}}}]}]}]';
			return json_decode($value, true);
		}
	}

	// create an option
	if( is_admin() ){ add_action('after_setup_theme', 'frmaster_cause_option_init'); }
	if( !function_exists('frmaster_cause_option_init') ){
		function frmaster_cause_option_init(){

			if( class_exists('frmaster_page_option') ){
				new frmaster_page_option(array(
					'post_type' => array('cause'),
					'title' => esc_html__('Cause Settings', 'frmaster'),
					'title-icon' => 'fa fa-gear',
					'slug' => 'gdlr-core-page-option',
					'options' => apply_filters('frmaster_cause_options', array(

						'general' => array(
							'title' => esc_html__('General', 'frmaster'),
							'options' => array(

								'enable-page-title' => array(
									'title' => esc_html__('Enable Page Title', 'frmaster'),
									'type' => 'checkbox',
									'default' => 'disable'
								),
								'caption' => array(
									'title' => esc_html__('Caption', 'frmaster'),
									'type' => 'textarea'
								),
								'funding-goal' => array(
									'title' => esc_html__('Funding Goal', 'frmaster'),
									'type' => 'text',
									'single' => 'frmaster-funding-goal',
									'description' => esc_html__('Please only fill number here.', 'frmaster')
								),
								'donor-amount' => array(
									'title' => esc_html__('Donor Amount', 'frmaster'),
									'type' => 'text',
									'single' => 'frmaster-donor-amount',
									'description' => esc_html__('This field will be automatically increased after the donation is completed.', 'frmaster')
								),
								'donated-amount' => array(
									'title' => esc_html__('Donated Amount', 'frmaster'),
									'type' => 'text',
									'single' => 'frmaster-donated-amount',
									'description' => esc_html__('This field will be automatically increased after the donation is completed.', 'frmaster')
								),


								'lightbox-video-url' => array(
									'title' => esc_html__('Thumbnail Lightbox Video URL', 'frmaster'),
									'type' => 'text',
								),
								'lightbox-gallery' => array(
									'title' => esc_html__('Thumbnail Lightbox Gallery', 'frmaster'),
									'type' => 'custom',
									'item-type' => 'gallery',
									'wrapper-class' => 'frmaster-fullsize',
								),
								'pdf-url' => array(
									'title' => esc_html__('Thumbnail PDF URL', 'frmaster'),
									'type' => 'text',
								),

							)
						), // general

						'social' => array(
							'title' => esc_html__('Social', 'frmaster'),
							'options' => array(

								'enable-social-share' => array(
									'title' => esc_html__('Enable Social Share', 'frmaster'),
									'type' => 'checkbox',
									'default' => 'enable'
								),
								'social-facebook' => array(
									'title' => esc_html__('Facebook', 'frmaster'),
									'type' => 'checkbox',
									'default' => 'enable',
									'condition' => array( 'enable-social-share' => 'enable' )
								),			
								'social-linkedin' => array(
									'title' => esc_html__('Linkedin', 'frmaster'),
									'type' => 'checkbox',
									'default' => 'disable',
									'condition' => array( 'enable-social-share' => 'enable' )
								),		
								'social-pinterest' => array(
									'title' => esc_html__('Pinterest', 'frmaster'),
									'type' => 'checkbox',
									'default' => 'enable',
									'condition' => array( 'enable-social-share' => 'enable' )
								),			
								'social-stumbleupon' => array(
									'title' => esc_html__('Stumbleupon', 'frmaster'),
									'type' => 'checkbox',
									'default' => 'disable',
									'condition' => array( 'enable-social-share' => 'enable' )
								),			
								'social-twitter' => array(
									'title' => esc_html__('Twitter', 'frmaster'),
									'type' => 'checkbox',
									'default' => 'enable',
									'condition' => array( 'enable-social-share' => 'enable' )
								),			
								'social-email' => array(
									'title' => esc_html__('Email', 'frmaster'),
									'type' => 'checkbox',
									'default' => 'disable',
									'condition' => array( 'enable-social-share' => 'enable' )
								),

							)
						),

						'payment' => array(
							'title' => esc_html__('Payment', 'frmaster'),
							'options' => array(
								'custom-payment-method' => array(
									'title' => esc_html__('Custom Payment Method', 'frmaster'),
									'type' => 'checkbox',
									'default' => 'disable',
								),
								'payment-method' => array(
									'title' => esc_html__('Payment Method', 'frmaster'),
									'type' => 'multi-combobox',
									'options' => array(
										'offline' => esc_html__('Offline', 'frmaster'),
										'paypal' => esc_html__('Online - Paypal', 'frmaster'),
										'credit-card' => esc_html__('Online - Credit Card', 'frmaster'),
									),
									'default' => array('offline', 'paypal', 'credit-card'),
									'description' => esc_html__('You can use Ctrl/Command button to select multiple items or remove the selected item.', 'frmaster'),
								),
								'credit-card-payment-gateway' => array(
									'title' => esc_html__('Credit Card Payment Gateway', 'frmaster'),
									'type' => 'combobox',
									'options' => apply_filters('frmaster_credit_card_payment_gateway_options', array('' => esc_html__('Default', 'frmaster'))),
								),
								
								'offline-payment-description' => array(
									'title' => esc_html__('Payment Bar - Offline Payment Description', 'frmaster'),
									'type' => 'textarea',
									'wrapper-class' => 'frmaster-fullsize'
								),
								'offline-payment-bank-name' => array(
									'title' => esc_html__('Offline Payment Bank Name', 'frmaster'),
									'type' => 'text'
								),
								'offline-payment-account-number' => array(
									'title' => esc_html__('Offline Payment Account Number', 'frmaster'),
									'type' => 'text'
								),
								'offline-payment-swift-code' => array(
									'title' => esc_html__('Offline Payment Swift Code', 'frmaster'),
									'type' => 'text'
								),
								'offline-payment-message' => array(
									'title' => esc_html__('Offline Payment Message', 'frmaster'),
									'type' => 'textarea'
								)
							)
						),

					)) // frmaster_cause_options
				)); // frmaster_page_option

			} // function_exits

		} // frmaster_cause_option_init
	}	

	if( !function_exists('frmaster_increase_donation_amount') ){
		function frmaster_increase_donation_amount($cause_id, $amount, $increase_donor = true){
			$donor_amount = get_post_meta($cause_id, 'frmaster-donor-amount', true);
			$donated_amount = get_post_meta($cause_id, 'frmaster-donated-amount', true);

			if( is_numeric($amount) ){
				if( $increase_donor ){
					$donor_amount++;
					update_post_meta($cause_id, 'frmaster-donor-amount', $donor_amount);
				}

				$donated_amount = floatval($donated_amount) + floatval($amount);
				update_post_meta($cause_id, 'frmaster-donated-amount', $donated_amount);
			}
		}
	}

	if( !function_exists('frmaster_get_follow_link') ){
		function frmaster_get_follow_link( $text = '', $link_class = 'frmaster-button frmaster-border-style' ){

			$logged_in = is_user_logged_in();

			$ret = '';
			if( !$logged_in ){
				$ret .= frmaster_lightbox_content(array(
					'id' => 'follow-login',
					'title' => esc_html__('Login', 'frmaster'),
					'content' => frmaster_get_login_form(false)
				));
				$ret .= '<a href="#" class="frmaster-follow ' . esc_attr($link_class) . '" data-frmlb="follow-login" >';
			}else{
				global $current_user;
				$follow_ids = get_user_meta($current_user->ID, 'frmaster-follow', true);
				$follow_ids = empty($follow_ids)? array(): $follow_ids;
				$follow_active = in_array(get_the_ID(), $follow_ids);

				if( $follow_active ){
					$ret .= '<a class="frmaster-follow ' . esc_attr($link_class) . ' frmaster-active" >';
				}else{
					$ret .= '<a href="#" class="frmaster-follow ' . esc_attr($link_class) . '" ';
					$ret .= ' data-ajax-url="' . esc_url(FRMASTER_AJAX_URL) . '" ';
					$ret .= ' data-cause-id="' . esc_attr(get_the_ID()) . '" >';
				}
			}
			if( empty($text) ){
				$ret .= '<i class="fa fa-heart-o" ></i>' . esc_html__('Follow', 'frmaster');
			}else{
				$ret .= frmaster_text_filter($text);
			}
			$ret .= '</a>';

			return $ret;
		}
	}

	if( !function_exists('frmaster_get_cause_social') ){
		function frmaster_get_cause_social($post_meta = array()){

			$url = get_permalink();
			$title = urlencode(html_entity_decode(get_the_title(), ENT_COMPAT, 'UTF-8'));

			$ret = '';

			if( !empty($post_meta['social-facebook']) && $post_meta['social-facebook'] == 'enable' ){
				$share_url = 'https://www.facebook.com/sharer/sharer.php?caption=' . $title . '&u=' . $url;
				$onclick_event = 'javascript:window.open(this.href,\'\', \'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=602,width=555\');return false;';

				$ret .= '<a class="gdlr-core-social-share-facebook" href="' . esc_url($share_url) . '" target="_blank" onclick="' . esc_attr($onclick_event) . '" ><i class="fa fa-facebook" ></i></a>';
			}

			if( !empty($post_meta['social-linkedin']) && $post_meta['social-linkedin'] == 'enable' ){
				$share_url = 'http://www.linkedin.com/shareArticle?mini=true&url=' . $url . '&title=' . $title;
				$onclick_event = 'javascript:window.open(this.href,\'\', \'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=452,width=550\');return false;';

				$ret .= '<a class="gdlr-core-social-share-linkedin" href="' . esc_url($share_url) . '" target="_blank" onclick="' . esc_attr($onclick_event) . '" ><i class="fa fa-linkedin" ></i></a>';
			}

			if( !empty($post_meta['social-pinterest']) && $post_meta['social-pinterest'] == 'enable' ){
				$share_url = 'http://pinterest.com/pin/create/button/?url=' . $url;
				if( has_post_thumbnail() ){
					$share_url .= '&media=' . wp_get_attachment_url(get_post_thumbnail_id(), 'large');
				}
				$onclick_event = 'javascript:window.open(this.href,\'\', \'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=553,width=750\');return false;';

				$ret .= '<a class="gdlr-core-social-share-pinterest" href="' . esc_url($share_url) . '" target="_blank" onclick="' . esc_attr($onclick_event) . '" ><i class="fa fa-pinterest-p" ></i></a>';
			}

			if( !empty($post_meta['social-stumbleupon']) && $post_meta['social-stumbleupon'] == 'enable' ){
				$share_url = 'http://www.stumbleupon.com/submit?url=' . $url . '&title=' . $title;
				$onclick_event = 'javascript:window.open(this.href,\'\', \'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=553,width=750\');return false;';

				$ret .= '<a class="gdlr-core-social-share-stumbleupon" href="' . esc_url($share_url) . '" target="_blank" onclick="' . esc_attr($onclick_event) . '" ><i class="fa fa-stumbleupon" ></i></a>';
			}

			if( !empty($post_meta['social-twitter']) && $post_meta['social-twitter'] == 'enable' ){
				$share_url = 'https://twitter.com/intent/tweet?text=' . $title . '&url=' . $url;
				$onclick_event = 'javascript:window.open(this.href,\'\', \'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=255,width=555\');return false;';

				$ret .= '<a class="gdlr-core-social-share-twitter" href="' . esc_url($share_url) . '" target="_blank" onclick="' . esc_attr($onclick_event) . '" ><i class="fa fa-twitter" ></i></a>';
			}

			if( !empty($post_meta['social-email']) && $post_meta['social-email'] == 'enable' ){
				$mail_title = esc_html__('Site sharing', 'goodlayers-core');
				$mail_body = esc_html__('Please check this site out', 'goodlayers-core');
				$share_url = "mailto:?subject={$mail_title}&amp;body={$mail_body} {$url}";

				$ret .= '<a class="gdlr-core-social-share-email" href="' . esc_url($share_url) . '" ><i class="fa fa-envelope" ></i></a>';
			}

			if( !empty($ret) ){
				$ret  = '<div class="frmaster-cause-social-share-wrap" >' . $ret . '</div>';
			}

			return $ret;

		} // frmaster_get_cause_social
	}